source('load.R')
dat = read.csv('data/dat_replication_20160628.csv')

# FORMULAS
f_baseline = list(
    int_treaty_med ~ int_effective_3n_med + W_cont_int_effective_med + gdppc_host + gdppc_home + inverse_distance + int_base_med + btt_n,
    roy_treaty_med ~ roy_effective_3n_med + W_cont_roy_effective_med + gdppc_host + gdppc_home + inverse_distance + roy_base_med + btt_n,
    div_treaty_med ~ div_effective_3n_med + W_cont_div_effective_med + gdppc_host + gdppc_home + inverse_distance + div_base_med + btt_n
    )
f_fw = list(
    int_treaty_med ~ int_effective_fw_med + W_cont_int_effective_med + gdppc_host + gdppc_home + inverse_distance + int_base_med + btt_n,
    roy_treaty_med ~ roy_effective_fw_med + W_cont_roy_effective_med + gdppc_host + gdppc_home + inverse_distance + roy_base_med + btt_n,
    div_treaty_med ~ div_effective_fw_med + W_cont_div_effective_med + gdppc_host + gdppc_home + inverse_distance + div_base_med + btt_n
    )
f_min = list(
    int_treaty_min ~ int_effective_3n_min + W_cont_int_effective_min + gdppc_host + gdppc_home + inverse_distance + int_base_min + btt_n,
    roy_treaty_min ~ roy_effective_3n_min + W_cont_roy_effective_min + gdppc_host + gdppc_home + inverse_distance + roy_base_min + btt_n,
    div_treaty_min ~ div_effective_3n_min + W_cont_div_effective_min + gdppc_host + gdppc_home + inverse_distance + div_base_min + btt_n
    )
f_max = list(
    int_treaty_max ~ int_effective_3n_max + W_cont_int_effective_max + gdppc_host + gdppc_home + inverse_distance + int_base_max + btt_n,
    roy_treaty_max ~ roy_effective_3n_max + W_cont_roy_effective_max + gdppc_host + gdppc_home + inverse_distance + roy_base_max + btt_n,
    div_treaty_max ~ div_effective_3n_max + W_cont_div_effective_max + gdppc_host + gdppc_home + inverse_distance + div_base_max + btt_n
    )
f_effective = list(
    int_effective_med ~ int_effective_3n_med + W_cont_int_effective_med + gdppc_host + gdppc_home + inverse_distance + int_base_med + btt_n,
    roy_effective_med ~ roy_effective_3n_med + W_cont_roy_effective_med + gdppc_host + gdppc_home + inverse_distance + roy_base_med + btt_n,
    div_effective_med ~ div_effective_3n_med + W_cont_div_effective_med + gdppc_host + gdppc_home + inverse_distance + div_base_med + btt_n
    )
f_between = list(
    int_treaty_med ~ int_effective_3n_med + gdppc_host + gdppc_home + inverse_distance + int_base_med + btt_n,
    roy_treaty_med ~ roy_effective_3n_med + gdppc_host + gdppc_home + inverse_distance + roy_base_med + btt_n,
    div_treaty_med ~ div_effective_3n_med + gdppc_host + gdppc_home + inverse_distance + div_base_med + btt_n
    )
f_gdp = list(
    int_treaty_med ~ int_effective_3n_med + W_cont_int_effective_med + gdp_host + gdp_home + gdppc_asymmetry + inverse_distance + int_base_med + btt_n,
    roy_treaty_med ~ roy_effective_3n_med + W_cont_roy_effective_med + gdp_host + gdp_home + gdppc_asymmetry  + inverse_distance + roy_base_med + btt_n,
    div_treaty_med ~ div_effective_3n_med + W_cont_div_effective_med + gdp_host + gdp_home + gdppc_asymmetry  + inverse_distance + div_base_med + btt_n
    )
f_econ = list(
    int_treaty_med ~ int_effective_3n_med + W_econ_int_effective_med + gdppc_host + gdppc_home + inverse_distance + int_base_med + btt_n,
    roy_treaty_med ~ roy_effective_3n_med + W_econ_roy_effective_med + gdppc_host + gdppc_home + inverse_distance + roy_base_med + btt_n,
    div_treaty_med ~ div_effective_3n_med + W_econ_div_effective_med + gdppc_host + gdppc_home + inverse_distance + div_base_med + btt_n
    )
f_dist = list(
    int_treaty_med ~ int_effective_3n_med + W_dist_int_effective_med + gdppc_host + gdppc_home + inverse_distance + int_base_med + btt_n,
    roy_treaty_med ~ roy_effective_3n_med + W_dist_roy_effective_med + gdppc_host + gdppc_home + inverse_distance + roy_base_med + btt_n,
    div_treaty_med ~ div_effective_3n_med + W_dist_div_effective_med + gdppc_host + gdppc_home + inverse_distance + div_base_med + btt_n
    )
f_nobtt = list(
    int_treaty_med ~ int_effective_3n_med + W_dist_int_effective_med + gdppc_host + gdppc_home + inverse_distance + int_base_med,
    roy_treaty_med ~ roy_effective_3n_med + W_dist_roy_effective_med + gdppc_host + gdppc_home + inverse_distance + roy_base_med,
    div_treaty_med ~ div_effective_3n_med + W_dist_div_effective_med + gdppc_host + gdppc_home + inverse_distance + div_base_med
    )


# MODELS
mod_baseline = lapply(f_baseline, lm, data=dat)
mod_fw = lapply(f_fw, lm, data=dat)
mod_min = lapply(f_min, lm, data=dat)
mod_max = lapply(f_max, lm, data=dat)
mod_effective = lapply(f_effective, lm, data=dat)
mod_gdp = lapply(f_gdp, lm, data=dat)
mod_econ = lapply(f_econ, lm, data=dat)
mod_dist = lapply(f_dist, lm, data=dat)
mod_nobtt = lapply(f_nobtt, lm, data=dat)
mod_robust = lapply(f_baseline, rlm, data=dat)
mod_tobit = lapply(f_baseline, function(i) vglm(i, tobit(Lower=0), data=dat))

vars = c('iso3c_host', unique(do.call('c', lapply(f_between, all.vars))))
dat_between = dat[, vars] %>% group_by(iso3c_host) %>%
              summarise_each(funs(mean(., na.rm=TRUE)))
mod_between = lapply(f_between, lm, data=dat_between)

# STANDARD ERRORS
f = function(x) sqrt(diag(sandwich(x)))
se_baseline = lapply(mod_baseline, f)
se_dist = lapply(mod_dist, f)
se_nobtt = lapply(mod_nobtt, f)
se_fw = lapply(mod_fw, f)
se_min = lapply(mod_min, f)
se_max = lapply(mod_max, f)
se_effective = lapply(mod_effective, f)
se_gdp = lapply(mod_gdp, f)
se_econ = lapply(mod_econ, f)
se_between = lapply(mod_between, f)
se_robust = lapply(mod_robust, f)

## WRITE
cmn = c('Interest', 'Royalties', 'Dividends')

lab = 'tab:baseline'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Relationship between direct and indirect withholding tax rates. OLS
       regression models with heteroskedasticity-consistent standard errors."
texreg(mod_baseline, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_baseline, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/baseline.tex', use.packages=FALSE)

lab = 'tab:fw'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Floyd-Warshall"
texreg(mod_fw, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_fw, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/fw.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:min'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Minimum withholding tax bracket"
texreg(mod_min, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_min, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/min.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:max'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Maximum withholding tax bracket"
texreg(mod_max, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_max, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/max.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:gdp'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP) host', 'log(GDP) home', 'GDP/capita asymmetry', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Control for GDP and asymmetry in GDP/capita."
texreg(mod_gdp, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_gdp, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/gdp.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:between'
ccn = c('Intercept', 'Indirect rate', 'log(GDP/cap) host', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Baseline rate', 'Indirect rate', 'Baseline rate')
cap = "Between model"
texreg(mod_between, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_between, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/between.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:effective'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Effective withholding tax rates"
texreg(mod_effective, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_effective, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/effective.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:economic'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Economic competition"
texreg(mod_econ, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_econ, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/economic.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:distance'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Population-weighted inverse distance competition"
texreg(mod_dist, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_dist, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/distance.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:robust'
ccn = c('Intercept', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Robust M-estimator"
texreg(mod_robust, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_robust, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/robust.tex', use.packages=FALSE, float.pos='b')

lab = 'tab:tobit'
ccn = c('Intercept 1', 'Intercept 2', 'Indirect rate', 'Diffusion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'log(BTTs)', 'Indirect rate', 'Diffusion', 'Baseline rate', 'Indirect rate', 'Diffusion', 'Baseline rate')
cap = "Tobit"
texreg(mod_tobit, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/tobit.tex', use.packages=FALSE, float.pos='b', bold=FALSE)

lab = 'tab:nobtt'
ccn = c('Intercept', 'Indirect rate', 'Contagion', 'log(GDP/cap) host', 'log(GDP/cap) home', 'Geographic proximity', 'Baseline rate', 'Indirect rate', 'Contagion', 'Baseline rate', 'Indirect rate', 'Contagion', 'Baseline rate')
cap = "No BTT control"
texreg(mod_nobtt, custom.coef.names=ccn, custom.model.names=cmn, digits=3,
       override.se=se_nobtt, stars=NULL, caption=cap, caption.above=TRUE, label=lab,
       booktabs=TRUE, file='fig/nobtt.tex', use.packages=FALSE, float.pos='b')

