source('load.R')

# FIGURE 1
dat = read.csv('data/dat_btt.csv')
p = ggplot(dat, aes(year, n)) + geom_line() +
    theme_bw() + xlab('Year') +
    ylab('Cumulative number of Bilateral Tax Treaties')
ggsave(p, file='fig/figure1.pdf', width=9, height=6)

# FIGURE 2
dat = read.csv('data/dat_withholdings.csv')
p = ggplot(dat, aes(Year, value, shape=variable)) + geom_point() + geom_line(linetype=3) +
    ylab('US-source income flows to \n foreign recipients (2010 USD)') +
    theme_minimal() + theme(legend.title=element_blank())
ggsave(plot=p, filename='fig/figure2.pdf', width=7.5, height=5)

# FIGURE 5
dat = read.csv('data/dat_replication_20160628.csv') %>%
      filter(!is.na(roy_treaty_med)) %>%
      dplyr::select(iso3c_host, iso3c_home, 
                    div_base_med, div_effective_3n_med, div_effective_med, 
                    int_base_med, int_effective_3n_med, int_effective_med, 
                    roy_base_med, roy_effective_3n_med, roy_effective_med) %>%
      melt(id.vars=c('iso3c_host', 'iso3c_home')) %>%
      mutate(Rate = 'Indirect',
             Rate = ifelse(grepl('base', variable), 'Base', Rate),
             Rate = ifelse(grepl('effective_med', variable), 'Effective', Rate),
             Flow = 'Royalties',
             Flow = ifelse(grepl('int', variable), 'Interest', Flow),
             Flow = ifelse(grepl('div', variable), 'Dividends', Flow)) %>%
      dplyr::select(-variable)

p = ggplot(dat, aes(value, color=Rate, linetype=Rate)) +
    stat_ecdf(geom = "step", size=1) +
    coord_fixed() +
    facet_grid(~ Flow, scales='free_x') +
    theme_bw() +
    xlab('Withholding Tax Rates') +
    ylab('Cumulative distribution') +
    theme_minimal() +
    xlim(c(0, 35)) +
    ylim(c(0, 1))
ggsave(p, file='fig/figure5.pdf', width=12, height=4)

# FIGURE 6
dat = read.csv('data/dat_replication_20160628.csv') %>%
      filter(!is.na(roy_treaty_med)) %>% # select treaty observations
      dplyr::select(iso3c_host, iso3c_home, 
                    roy_effective_3n_0, roy_effective_3n_25, 
                    roy_effective_3n_50, roy_effective_3n_100,
                    int_effective_3n_0, int_effective_3n_25, 
                    int_effective_3n_50, int_effective_3n_100,
                    div_effective_3n_0, div_effective_3n_25, 
                    div_effective_3n_50, div_effective_3n_100) %>%
      melt(id.vars=c('iso3c_host', 'iso3c_home')) %>%
      mutate(Flow = 'Royalties',
             Flow = ifelse(grepl('^int', variable), 'Interest', Flow),
             Flow = ifelse(grepl('^div', variable), 'Dividends', Flow), 
             BTTs = 'None',
             BTTs = ifelse(grepl('25', variable), '25%', BTTs),
             BTTs = ifelse(grepl('50', variable), '50%', BTTs),
             BTTs = ifelse(grepl('100', variable), 'All', BTTs))
p = ggplot(dat, aes(value, color=BTTs, linetype=BTTs)) +
    stat_ecdf(geom = "step", size=1) +
    coord_fixed() +
    facet_grid(~ Flow, scales='free_x') +
    theme_bw() +
    xlab('Indirect Tax Rates') +
    ylab('Cumulative distribution') +
    theme_minimal() +
    xlim(c(0, 35)) +
    ylim(c(0, 1))
ggsave(p, file='fig/figure6.pdf', width=12, height=4)

# FIGURE 7
dat = read.csv('data/dat_replication_20160628.csv') %>% 
      dplyr::select(iso3c_host, iso3c_home, 
                    div_effective_3n_med, div_effective_med, 
                    int_effective_3n_med, int_effective_med, 
                    roy_effective_3n_med, roy_effective_med) %>%
      melt(id.vars=c('iso3c_host', 'iso3c_home')) %>%
      mutate(Flow = 'Royalties',
             Flow = ifelse(grepl('^int', variable), 'Interest', Flow),
             Flow = ifelse(grepl('^div', variable), 'Dividends', Flow), 
             Rate = 'Indirect',
             Rate = ifelse(grepl('effective_med', variable), 'Direct', Rate)) %>%
      dplyr::select(-variable) %>%
      dcast(iso3c_host + iso3c_home + Flow ~ Rate)

p = ggplot(dat, aes(Direct, Indirect)) +
    geom_point(alpha=.3) +
    geom_smooth(se=FALSE) +
    theme_minimal() +
    facet_wrap(~Flow)
ggsave(p, file='fig/figure7.pdf', width=12, height=4)
